# theme/mono.rb, copyright (c) 2007 by Vincent Fourmond: 
# The "mono" theme
  
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
  
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details (in the COPYING file).


require 'CTioga/themes/classical'

module CTioga
  
  module Themes
    
    class MonoTheme < ClassicalTheme
      
      def initialize
        super(Tioga::FigureConstants::Black, 'standard', 
              Tioga::FigureConstants::Black, 'standard')
      end


    end

  end

end
